@@ -160,9 +160,11 @@ class STAClient:
         ds_id = self.get_datastream_id(name, thing_id)
         if ds_id:
             self.patch_datastream(ds_id, payload)
+            added = False
         else:
             ds_id = self._add('Datastreams', payload)
-        return ds_id
+            added = True
+        return ds_id, added
 
     def get_sensor(self, name):
         return self._get_id('Sensors', name)
@@ -192,7 +194,7 @@ class STAClient:
     def delete(self, url):
         resp = requests.delete(url,
                                auth=(self._user, self._pwd))
-        if resp.status_code!=200:
+        if resp.status_code != 200:
             logging.info(resp, resp.text)
 
     def patch(self, url, payload):
@@ -302,7 +304,7 @@ class STAClient:
             comp = 'eq'
             return f'?filter={k} {comp} {v}'
 
-        fs = [factory(k,v) for k,v in filters.items()]
+        fs = [factory(k, v) for k, v in filters.items()]
         fs = '&'.join(fs)
         return f'{tag}?{fs}'
 
